WORK IN PROGRESS, DON'T USE IT YET


TODO:

- get out of str/obj comparision in plugins/routes

- rate limiting middleware
- request size limiting middleware
- clean tests output
- websockets support
- blacklists middleware
- Caching middleware
- CORS
- routing tests for path stuff

- Monitoring: statsd
- Health Checks
- brama docs


